<?php 
/**
 * Theme: Swipy
 * 
 * Theme Functions, includes, etc.
 *
 * @package swipy
 */


// Load theme languages
load_theme_textdomain( 'swp', get_template_directory().'/languages' );


/* ------------------------------------------------------------------------- *
 *  Include Functional File
/* ------------------------------------------------------------------------- */	

		
	require_once('functions/wp_bootstrap_navwalker.php');   	// script for bootstrap menu 
	


/* ------------------------------------------------------------------------- *
 *  Base functionality
/* ------------------------------------------------------------------------- */	


	// Content width
	if ( !isset( $content_width ) ) { $content_width = 720; }
	

/*  Theme setup
/* ------------------------------------ */
if ( ! function_exists( 'fullbase_setup' ) ) {
	
	function fullbase_setup() {	
		
		add_theme_support( "title-tag" );
		
		// Enable automatic feed links
		add_theme_support( 'automatic-feed-links' );
		
		// Enable featured image
		add_theme_support( 'post-thumbnails' );
		
		// Enable post format support
		//add_theme_support( 'post-formats', array( 'audio', 'aside', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' ) );
		
		// Declare WooCommerce support
		//add_theme_support( 'woocommerce' );
		
		// Thumbnail sizes
		add_image_size( 'thumb', 200, 124, true ); 	//(cropped)
		add_image_size( 'single', 800, 493, true ); //(cropped)
		add_image_size( 'big', 1600, 700, true ); 	//(cropped)

		// Custom menu areas
		register_nav_menus( array(
			'header' => 'Header',
			//'footer' => 'Footer',
		) );
	}
	
}
add_action( 'after_setup_theme', 'fullbase_setup' );



/*  Register sidebars
/* ------------------------------------ */	
if ( ! function_exists( 'fullbase_sidebars' ) ) {
	

	function fullbase_sidebars()	{
		register_sidebar(array( 'name' => 'Primary','id' => 'primary','description' => "Normal full width sidebar", 'before_widget' => '<div  class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3>','after_title' => '</h3>'));
		register_sidebar(array( 'name' => 'Home','id' => 'home-page-laoyout','description' => "Home layout with parallax.", 'before_widget' => '<div id="%1$s" class="widget %2$s">','after_widget' => '</div>','before_title' => '<h3>','after_title' => '</h3>'));
	}
	
}
add_action( 'widgets_init', 'fullbase_sidebars' );


/*  Enqueue javascript
/* ------------------------------------ */	
if ( ! function_exists( 'fullbase_scripts' ) ) {
	
	function fullbase_scripts() {
		
		// all script
		wp_enqueue_script('jquery');
		
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'gallery-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.js', array( 'jquery' ),null,true );
		wp_enqueue_script( 'flickity', get_template_directory_uri() . '/js/flickity.pkgd.min.js', array( 'jquery' ),null,true );
		//wp_enqueue_script( 'core', get_template_directory_uri() . '/js/core.min.js', array( 'jquery' ),null,true );
		
		wp_enqueue_script( 'scripts', get_template_directory_uri() . '/js/script.js', array( 'jquery' ),'', true );

			$array = array(
				"path_wp" => home_url().'/',
			);
		    wp_localize_script( "scripts", "php_vars", $array );

		
		
		if ( is_singular() && get_option( 'thread_comments' ) )	{ wp_enqueue_script( 'comment-reply' ); }
	}  
	
}
add_action( 'wp_enqueue_scripts', 'fullbase_scripts' ); 


/*  Enqueue css
/* ------------------------------------ */	
if ( ! function_exists( 'fullbase_styles' ) ) {
	
	function fullbase_styles() {
		wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.min.css');
		wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.css');
		wp_enqueue_style( 'gallery-popup', get_template_directory_uri().'/css/magnific-popup.css');
		wp_enqueue_style( 'flickity', get_template_directory_uri().'/css/flickity.min.css');
		//wp_enqueue_style( 'core', get_template_directory_uri().'/css/core.min.css');
		
		wp_enqueue_style( 'sourcesanspro','http://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,700');
		wp_enqueue_style( 'screen', get_template_directory_uri().'/style.css');
		
	}
	
}
add_action( 'wp_enqueue_scripts', 'fullbase_styles' );

/* ------------------------------------------------------------------------- *
 *  General 
/* ------------------------------------------------------------------------- */	

	/* Remove Header Unnecessary Code */
	remove_action('wp_head', 'feed_links_extra', 3 ); // Show only main RSS feed and remove the other feeds */
	remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0 );
	remove_action('wp_head', 'wlwmanifest_link'); // remove wlwmanifest.xml (needed to support windows live writer)
	
	/*  Disable Gallery Inline Style
	/* ------------------------------------ */
	add_filter( 'use_default_gallery_style', '__return_false' );
	
	/*  Oembed Responsive
	/* ------------------------------------ */
	add_filter( 'embed_oembed_html', 'tdd_oembed_filter', 10, 4 ) ;

	function tdd_oembed_filter($html, $url, $attr, $post_ID) {
		$return = '<figure class="video-container">'.$html.'</figure>';
		return $return;
	}

	/*  Enable hr button tiny MCE
	/* ------------------------------------ */	
	function enable_more_buttons($buttons) {
	  $buttons[] = 'hr';
	  return $buttons;
	}
	add_filter("mce_buttons", "enable_more_buttons");
	
	
	/*  Remove P in description output
	/* ------------------------------------ */	
	remove_filter('term_description','wpautop');
	
	
	/*  Add Excerpt on Pages for Seo description
	/* ------------------------------------ */	
	add_action( 'init', 'fullbase_add_excerpts_to_pages' );
	function fullbase_add_excerpts_to_pages() {
	     add_post_type_support( 'page', 'excerpt' );
	}

	/*  Adjust excerpt lenght
	/* ------------------------------------ */	
	function custom_excerpt_length( $length ) {
		return 30;
	}
	add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

	/*  Change excerpt icon
	/* ------------------------------------ */	
	function new_excerpt_more( $more ) {
		return ' <a class="read-more" href="' . get_permalink( get_the_ID() ) . '"> [...] <i class="fa fa-angle-double-right"></i> </a>';
	}
	add_filter( 'excerpt_more', 'new_excerpt_more' );

	/*  Change read more icon
	/* ------------------------------------ */	
	add_filter( 'the_content_more_link', 'modify_read_more_link' );
	function modify_read_more_link() {
		return '<a href="' . get_permalink() . '"> [...] <i class="fa fa-angle-double-right"></i> </a>';
	}
	
	/* Add images to RSS Feed
	/* ------------------------------------ */	
	function rss_post_thumbnail($content) {
		
		global $post;
		
		if(has_post_thumbnail($post->ID)) {
		
			$content = '<p>' . get_the_post_thumbnail($post->ID, 'single') . '</p>' . get_the_content();
			$content = preg_replace("/\[caption.*\[\/caption\]/", '',$content);
			
		}
		
		return $content;
	}
	add_filter('the_excerpt_rss', 'rss_post_thumbnail');
	add_filter('the_content_feed', 'rss_post_thumbnail');



/* ------------------------------------------------------------------------- *
 *  Include the TGM_Plugin_Activation class.
/* ------------------------------------------------------------------------- */	


require_once dirname( __FILE__ ) . '/functions/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'my_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function my_theme_register_required_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		/** This is an example of how to include a plugin pre-packaged with a theme */
		array(
			'name'     => 'Swipy Plugin Bundle', 	// The plugin name
			'slug'     => 'swipy-plugin', 			// The plugin slug (typically the folder name)
			'source'   => get_stylesheet_directory() . '/functions/swipy-plugin.zip', // The plugin source
			'required' => true,
		)
	);

	/** Change this to your theme text domain, used for internationalising strings */
	$theme_text_domain = 'tgmpa';

	/**
	 * Array of configuration settings. Uncomment and amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * uncomment the strings and domain.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		/*'domain'       => $theme_text_domain,         // Text domain - likely want to be the same as your theme. */
		/*'default_path' => '',                         // Default absolute path to pre-packaged plugins */
		/*'menu'         => 'install-my-theme-plugins', // Menu slug */
		'strings'      	 => array(
			/*'page_title'             => __( 'Install Required Plugins', $theme_text_domain ), // */
			/*'menu_title'             => __( 'Install Plugins', $theme_text_domain ), // */
			/*'instructions_install'   => __( 'The %1$s plugin is required for this theme. Click on the big blue button below to install and activate %1$s.', $theme_text_domain ), // %1$s = plugin name */
			/*'instructions_activate'  => __( 'The %1$s is installed but currently inactive. Please go to the <a href="%2$s">plugin administration page</a> page to activate it.', $theme_text_domain ), // %1$s = plugin name, %2$s = plugins page URL */
			/*'button'                 => __( 'Install %s Now', $theme_text_domain ), // %1$s = plugin name */
			/*'installing'             => __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name */
			/*'oops'                   => __( 'Something went wrong with the plugin API.', $theme_text_domain ), // */
			/*'notice_can_install'     => __( 'This theme requires the %1$s plugin. <a href="%2$s"><strong>Click here to begin the installation process</strong></a>. You may be asked for FTP credentials based on your server setup.', $theme_text_domain ), // %1$s = plugin name, %2$s = TGMPA page URL */
			/*'notice_cannot_install'  => __( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', $theme_text_domain ), // %1$s = plugin name */
			/*'notice_can_activate'    => __( 'This theme requires the %1$s plugin. That plugin is currently inactive, so please go to the <a href="%2$s">plugin administration page</a> to activate it.', $theme_text_domain ), // %1$s = plugin name, %2$s = plugins page URL */
			/*'notice_cannot_activate' => __( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', $theme_text_domain ), // %1$s = plugin name */
			/*'return'                 => __( 'Return to Required Plugins Installer', $theme_text_domain ), // */
		),
	);

	tgmpa( $plugins, $config );

}

/* ------------------------------------------------------------------------- *
 *  CUSTOM PAGE - Premium Version
/* ------------------------------------------------------------------------- */	

add_action( 'admin_menu', 'register_my_custom_menu_page' );

function register_my_custom_menu_page(){
    add_menu_page( 'SWIPY Plus', 'SWIPY Plus', 'manage_options', 'custompage', 'my_custom_menu_page', get_template_directory_uri() . '/img/icon-backend.png', 99); 
}

function my_custom_menu_page(){ ?>
<div style="float:left; padding:3% 5% 5% 5%; width:90%; ">

   <h1>Why update to SWIPY Plus ?</h1>
   <h2>A lot of new features for awesome site with easy customization..</h2>
   
   <img src="<?php echo get_template_directory_uri(); ?>/img/features-2.jpg" style="width:100%; height:auto; float:left;margin-right:20%; margin-top:20px;"/>
   
   <p style="font-size:20px; margin: 20px 0;float:left; width:100%;"> <a href="http://www.marchettidesign.net/swipy/" target="_blank">Watch all the features!</a> <br/> Have questions? <a href="http://www.marchettidesign.net/contatti/" target="_blank">Contact me</a>.</p>
   
   <a href="http://www.marchettidesign.net/swipy/demo" target="_blank" style="float:left; display:block; padding: 15px 40px; margin-right:20px; border-radius: 4px;color:#fff; background:#00acf2; font-weight:700; text-decoration:none">LIVE DEMO</a>

   <a href="http://www.marchettidesign.net/shop/cart/?add-to-cart=1416" target="_blank" style="float:left; display:block; padding: 15px 40px; margin-right:20px; border-radius: 4px;color:#fff; background:#fc4f56; font-weight:700; text-decoration:none">BUY PREMIUM 19$</a>
   
</div>
     
<?php } ?>
