<?php

/* ------------------------------------------------------------------------- *
 *   Parallax Image Widget - based on original widget of http://swppb.com/ 
/* ------------------------------------------------------------------------- */ 

/**
 * Image Upload Widget
 */
class Swipy_Image_Widget extends WP_Widget {

    // Holds widget settings defaults, populated in constructor.
    protected $defaults;

    // Constructor. Set the default widget options and create widget.
    function __construct() {

        $this->defaults = array(
            'title' => '',
            'text'  => '',
            'image' => '',
            'link'  => '',
        );

        $widget_ops = array(
            'classname'   => 'swppb-media-widget',
            'description' => __( 'Add a Parallax image.', 'swipy-plugin' ),
        );

        $control_ops = array(
            'id_base' => 'swppb-media-widget',
            'width'   => 200,
            'height'  => 250,
        );

        parent::__construct( 'swppb-media-widget', __( 'SWIPY - Parallax Image', 'swipy-plugin' ), $widget_ops, $control_ops );

    }

    // The widget content.
    function widget( $args, $instance ) {

        //* Merge with defaults
        $instance = wp_parse_args( (array) $instance, $this->defaults );

        ?>

            <!-- Parallax Image -->
            <section class="container-panel parallax-section parallax-animation " style="background: #585152 url('<?php 

                $image_url =  wp_get_attachment_image_src( $instance['image'] , 'big' ); 
                echo $image_url[0]; 

                ?>') no-repeat top center fixed; background-size: cover;" id="<?php echo sanitize_title( $instance['title'] ); ?>">
                
                <div class="parallax-caption">

                    <?php if ( ! empty( $instance['title'] ) ) {

                        echo '<h2>';

                        echo ( ! empty( $instance['link'] ) ) ? '<a href="' . $instance['link'] . '">' : '';

                        echo  apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base );

                        echo ( ! empty( $instance['link'] ) ) ? '</a>' : '';

                        echo '</h2>';

                    } ?>

                    <?php echo ( ! empty( $instance['text'] ) ) ? '<h3>' .$instance['text'] . '</h3>' : '';  ?>
                   
                </div>

            </section>

        <?php

    }

    // Update a particular instance.
    function update( $new_instance, $old_instance ) {

        $new_instance['title']  = strip_tags( $new_instance['title'] );
        $new_instance['text']   = strip_tags( $new_instance['text'] );
        $new_instance['image']  = strip_tags( $new_instance['image'] );
        $new_instance['link']   = strip_tags( $new_instance['link'] );

        return $new_instance;

    }

    // The settings update form.
    function form( $instance ) {

        // Merge with defaults
        $instance = wp_parse_args( (array) $instance, $this->defaults );

        ?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'swipy-plugin' ); ?>:</label>
            <input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
            <small class="swppb-slug"><strong>Slug panel:</strong>  #<?php echo sanitize_title( $instance['title'] ); ?></small>
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'image' ); ?>"><?php _e( 'Image', 'swipy-plugin' ); ?>:</label>
            <div class="swppb-media-container">
                <div class="swppb-media-inner">
                    <?php $img_style = ( $instance[ 'image' ] != '' ) ? '' : 'style="display:none;"'; ?>
                    <img id="<?php echo $this->get_field_id( 'image' ); ?>-preview" src="<?php 

                        $image_url =  wp_get_attachment_image_src( $instance['image'] , 'single' ); 
                        echo $image_url[0];

                    ?>" <?php echo $img_style; ?> />
                    <?php $no_img_style = ( $instance[ 'image' ] != '' ) ? 'style="display:none;"' : ''; ?>
                    <span class="swppb-no-image" id="<?php echo $this->get_field_id( 'image' ); ?>-noimg" <?php echo $no_img_style; ?>><?php _e( 'No image selected', 'swipy-plugin' ); ?></span>
                </div>
            
            <input type="text" id="<?php echo $this->get_field_id( 'image' ); ?>" name="<?php echo $this->get_field_name( 'image' ); ?>" value="<?php echo esc_attr( $instance['image'] ); ?>" class="swppb-media-url" />

            <input type="button" value="<?php echo _e( 'Remove', 'swipy-plugin' ); ?>" class="button swppb-media-remove" id="<?php echo $this->get_field_id( 'image' ); ?>-remove" <?php echo $img_style; ?> />

            <?php $button_text = ( $instance[ 'image' ] != '' ) ? __( 'Change Image', 'swipy-plugin' ) : __( 'Select Image', 'swipy-plugin' ); ?>
            <input type="button" value="<?php echo $button_text; ?>" class="button swppb-media-upload" id="<?php echo $this->get_field_id( 'image' ); ?>-button" />
            <br class="clear">
            </div>
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'text' ); ?>"><?php _e( 'Description', 'swipy-plugin' ); ?>:</label>
            <textarea class="widefat" rows="4" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo esc_attr( $instance['text'] ); ?></textarea>
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e( 'URL', 'swipy-plugin' ); ?>:</label>
            <input type="text" id="<?php echo $this->get_field_id( 'link' ); ?>" name="<?php echo $this->get_field_name( 'link' ); ?>" value="<?php echo esc_attr( $instance['link'] ); ?>" class="widefat" />
        </p>

        <?php

    }

}


/**
 * Register Widget
 */
function register_Swipy_Image_Widget() { 
  
    register_widget( 'Swipy_Image_Widget' ); 

} 
add_action( 'widgets_init','register_Swipy_Image_Widget' );


?>