<?php

/* ------------------------------------------------------------------------- *
 *   Page Widget
/* ------------------------------------------------------------------------- */ 
 
class Swipy_Page_Widget extends WP_Widget {
	
	// Holds widget settings defaults, populated in constructor.
	
    protected $defaults;

    // Constructor. Set the default widget options and create widget.
    
    function __construct() {

        $this->defaults = array(
            'title' => '',
            'page_sel'  => '',
            'flip_page' => '',
          
        );

        $widget_ops = array(
            'classname'   => 'swppb-page-widget',
            'description' => __( 'Show a page from the page list.', 'swipy-plugin' ),
        );

        $control_ops = array(
            'id_base' => 'swppb-page-widget',
            'width'   => 200,
            'height'  => 250,
        );

        parent::__construct( 'swppb-page-widget', __( 'SWIPY - Page', 'swipy-plugin' ), $widget_ops, $control_ops );

    }


    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
     
    function widget( $args, $instance ) {
    
       //* Merge with defaults
        $instance = wp_parse_args( (array) $instance, $this->defaults );

        ?>

            <?php /* Box Page */

            if(  $instance['page_sel']  != '') { // if page is selected show the page 

                $loopPage = new WP_Query();
                $loopPage->query('page_id='. $instance['page_sel'] ); // id page selcted
                
                
                ?>

                <?php if ($loopPage->have_posts()) : while($loopPage->have_posts()) : $loopPage->the_post(); ?>
                    
                    <!-- Page -->
                    <section class="container-panel">
                        <span class="scroll-anchor" id="<?php echo sanitize_title( $instance['title'] ); ?>"></span>
                        <div class="container container-2-box">
                            
                            <div class="row">

                                <?php if ( has_post_thumbnail() ) { /* if image thumbnail is set */ ?>

                                    <div class="col-md-6 <?php if( $instance['flip_page'] == '1' ) { echo ' col-md-push-6'; } ?>">
                                        <h2><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h2>
                                        <?php  /* If exist show subtitle */
                                        $subtitle = get_post_meta( get_the_ID(), 'meta-text', true );
                                        echo ( ! empty( $subtitle ) ) ? '<h3>' . $subtitle . '</h3>' : '';
                                        ?><a href="<?php the_permalink(); ?>" class="btn-call"><?php _e('Discover more <i class="fa fa-angle-right"></i>','swipy-plugin');?></a>
                                    </div>
                                    <div class="col-md-6 <?php if( $instance['flip_page'] == '1' ) { echo ' col-md-pull-6'; } ?>">
                                        <?php the_post_thumbnail('single', array('class' => 'img-res','alt' => get_the_title())); ?>
                                    </div>

                                <?php } else { /* if no image set */?>

                                    <div class="col-md-8 col-md-offset-2 text-center margin-bottom">

                                        <h2><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h2>
                                        <?php  /* If exist show subtitle */
                                        $subtitle = get_post_meta( get_the_ID(), 'meta-text', true );
                                        echo ( ! empty( $subtitle ) ) ? '<h3>' . $subtitle . '</h3>' : '';
                                        ?>
                                        <?php the_content(); ?>

                                    </div>

                                <?php } ?>
                            </div>

                        </div>
                    </section>

                <?php endwhile; endif; wp_reset_query(); ?>
            
            <?php } else { ?>

                <h2 class="text-center"> Please set a Title Select and Page in the <a href="<?php echo get_bloginfo('url'); ?>/wp-admin/widgets.php">Widget</a>. </h2>

            <?php } ?>    

    <?php
        
    }
    
     /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    
    function update( $new_instance, $old_instance ) {
        
        $new_instance['title']  = strip_tags( $new_instance['title'] );
        $new_instance['page_sel']   = strip_tags( $new_instance['page_sel'] );
        $new_instance['flip_page']   = strip_tags( $new_instance['flip_page'] );

        return $new_instance;
        
    }


    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
     
    function form( $instance ) {
	    
	     // Merge with defaults
        $instance = wp_parse_args( (array) $instance, $this->defaults );
    
    ?>  
       
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title / Slug:', 'swipy-plugin'); ?></label><br/>
            <input style="width:100%"id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title']; ?>" />
            <small class="swppb-slug"><strong>Slug panel:</strong>  #<?php echo sanitize_title( $instance['title'] ); ?></small>
        </p>
        
        <p><?php _e('Choose a page to show:', 'swipy-plugin');
          
            $args = array(
					'id' 	=> $this->get_field_id('page_sel'),
					'name' 	=> $this->get_field_name('page_sel'),
					'selected' =>  $instance['page_sel']
		    );
			wp_dropdown_pages( $args );
			?>
		</p>

        <p>
            
            <input id="<?php echo $this->get_field_id('flip_page'); ?>" name="<?php echo $this->get_field_name('flip_page'); ?>" type="checkbox" value="1" <?php checked( '1', $instance['flip_page'] ); ?> />
            <label for="<?php echo $this->get_field_id('flip_page'); ?>"><?php _e('Flip image and text Horizontally', 'swipy-plugin'); ?></label>
        </p>

        
    <?php 
    }

} // class Swipy_Page_Widget

// register Swipy_Page_Widget widget
function register_Swipy_Page_Widget() {
    register_widget( 'Swipy_Page_Widget' );
}
add_action( 'widgets_init', 'register_Swipy_Page_Widget' );

?>