<?php

/* ------------------------------------------------------------------------- *
 *   Slider Widget
/* ------------------------------------------------------------------------- */ 
 
class Swipy_Slider_Widget extends WP_Widget {
	
	// Holds widget settings defaults, populated in constructor.
	
    protected $defaults;

    // Constructor. Set the default widget options and create widget.
    
    function __construct() {

        $this->defaults = array(
            'title' => '',
            'page_1_sel'  => '',
            'page_2_sel' => '',
            'page_3_sel'  => '',
        );

        $widget_ops = array(
            'classname'   => 'swppb-slider-widget',
            'description' => __( 'Add a Slider with 4 pages from the page list.', 'swipy-plugin' ),
        );

        $control_ops = array(
            'id_base' => 'swppb-slider-widget',
            'width'   => 200,
            'height'  => 250,
        );

        parent::__construct( 'swppb-slider-widget', __( 'SWIPY - Slider', 'swipy-plugin' ), $widget_ops, $control_ops );

    }


    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    
    function widget( $args, $instance ) {
    
        //* Merge with defaults
        $instance = wp_parse_args( (array) $instance, $this->defaults );
       
        //echo $title; //hide title
        
        ?>  

        <!-- Slider -->        
        <div class="slider js-flickity" data-flickity-options='{ "imagesLoaded": true, "autoPlay": 6000 , "prevNextButtons": false, "accessibility": false }' id="<?php echo sanitize_title( $instance['title'] ); ?>">
			 	
			<?php loopSliderBox( $instance['page_1_sel'] , true); ?>
            <?php loopSliderBox( $instance['page_2_sel'], false); ?>
            <?php loopSliderBox( $instance['page_3_sel'], false); ?>
            
        </div>


    <?php
        
    }
    
     /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    
    function update( $new_instance, $old_instance ) {
	    
        $new_instance['title']  = strip_tags( $new_instance['title'] );
        $new_instance['page_1_sel']   = strip_tags( $new_instance['page_1_sel'] );
        $new_instance['page_2_sel']   = strip_tags( $new_instance['page_2_sel'] );
        $new_instance['page_3_sel']   = strip_tags( $new_instance['page_3_sel'] );

        return $new_instance;
    }


    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
     
    function form( $instance ) {
    
        // Merge with defaults
        $instance = wp_parse_args( (array) $instance, $this->defaults );

    ?>  
        
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title / Slug:', 'swipy-plugin'); ?></label><br/>
            <input style="width:100%"id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title']; ?>" />
            <small class="swppb-slug"><strong>Slug panel:</strong>  #<?php echo sanitize_title( $instance['title'] ); ?></small>
        </p>
        
        <p><?php _e('Choose a page to show:', 'swipy-plugin');
          
            $args = array(
					'id' 	=> $this->get_field_id('page_1_sel'),
					'name' 	=> $this->get_field_name('page_1_sel'),
					'selected' => $instance['page_1_sel']
		    );
			wp_dropdown_pages( $args );
			?>
		</p>

        <p><?php _e('Choose a page to show:', 'swipy-plugin');
          
            $args = array(
					'id' 	=> $this->get_field_id('page_2_sel'),
					'name' 	=> $this->get_field_name('page_2_sel'),
					'selected' => $instance['page_2_sel']
		    );
			wp_dropdown_pages( $args );
			?>
		</p>

        <p><?php _e('Choose a page to show:', 'swipy-plugin');
          
            $args = array(
					'id' 	=> $this->get_field_id('page_3_sel'),
					'name' 	=> $this->get_field_name('page_3_sel'),
					'selected' => $instance['page_3_sel']
		    );
			wp_dropdown_pages( $args );
			?>
		</p>
   
    <?php 
    }

  
} // class Swipy_Slider_Widget

// register Swipy_Slider_Widget widget
function register_Swipy_Slider_Widget() {
    register_widget( 'Swipy_Slider_Widget' );
}
add_action( 'widgets_init', 'register_Swipy_Slider_Widget' );

?>